@@ -4,10 +4,14 @@
  */
 
 mod dns;
+/// Proxy configuration
+pub mod proxy;
 mod timeout;
 /// TLS connector(s)
 pub mod tls;
 
+pub(crate) mod connect;
+
 use crate::cfg::cfg_tls;
 use crate::tls::TlsContext;
 use aws_smithy_async::future::timeout::TimedOutError;
@@ -39,7 +43,8 @@ use hyper_util::client::legacy::connect::dns::GaiResolver;
 use hyper_util::client::legacy::connect::{
     capture_connection, CaptureConnection, Connect, HttpConnector as HyperHttpConnector, HttpInfo,
 };
-use hyper_util::rt::TokioExecutor;
+use hyper_util::client::proxy::matcher::Matcher;
+use hyper_util::rt::{TokioExecutor, TokioTimer};
 use std::borrow::Cow;
 use std::collections::HashMap;
 use std::error::Error;
@@ -103,23 +108,26 @@ impl HttpConnector for Connector {
 }
 
 /// Builder for [`Connector`].
-#[derive(Default, Debug)]
+#[derive(Default, Debug, Clone)]
 pub struct ConnectorBuilder<Tls = TlsUnset> {
     connector_settings: Option<HttpConnectorSettings>,
     sleep_impl: Option<SharedAsyncSleep>,
     client_builder: Option<hyper_util::client::legacy::Builder>,
+    pool_idle_timeout: Option<Option<Duration>>,
     enable_tcp_nodelay: bool,
     interface: Option<String>,
+    proxy_config: Option<proxy::ProxyConfig>,
     #[allow(unused)]
     tls: Tls,
 }
 
 /// Initial builder state, `TlsProvider` choice required
-#[derive(Default)]
+#[derive(Default, Debug, Clone)]
 #[non_exhaustive]
 pub struct TlsUnset {}
 
 /// TLS implementation selected
+#[derive(Debug, Clone)]
 pub struct TlsProviderSelected {
     #[allow(unused)]
     provider: tls::Provider,
@@ -136,6 +144,8 @@ impl ConnectorBuilder<TlsUnset> {
             client_builder: self.client_builder,
             enable_tcp_nodelay: self.enable_tcp_nodelay,
             interface: self.interface,
+            proxy_config: self.proxy_config,
+            pool_idle_timeout: self.pool_idle_timeout,
             tls: TlsProviderSelected {
                 provider,
                 context: TlsContext::default(),
@@ -146,8 +156,30 @@ impl ConnectorBuilder<TlsUnset> {
     /// Build an HTTP connector sans TLS
     #[doc(hidden)]
     pub fn build_http(self) -> Connector {
+        if let Some(ref proxy_config) = self.proxy_config {
+            if proxy_config.requires_tls() {
+                tracing::warn!(
+                    "HTTPS proxy configured but no TLS provider set. \
+                     Connections to HTTPS proxy servers will fail. \
+                     Consider configuring a TLS provider to enable TLS support."
+                );
+            }
+        }
+
         let base = self.base_connector();
-        self.wrap_connector(base)
+
+        // Wrap with HTTP proxy support if proxy is configured
+        let proxy_config = self
+            .proxy_config
+            .clone()
+            .unwrap_or_else(proxy::ProxyConfig::disabled);
+
+        if !proxy_config.is_disabled() {
+            let http_proxy_connector = connect::HttpProxyConnector::new(base, proxy_config);
+            self.wrap_connector(http_proxy_connector)
+        } else {
+            self.wrap_connector(base)
+        }
     }
 }
 
@@ -163,11 +195,9 @@ impl<Any> ConnectorBuilder<Any> {
         C::Future: Unpin + Send + 'static,
         C::Error: Into<BoxError>,
     {
-        let client_builder =
-            self.client_builder
-                .unwrap_or(hyper_util::client::legacy::Builder::new(
-                    TokioExecutor::new(),
-                ));
+        let client_builder = self
+            .client_builder
+            .unwrap_or_else(|| new_tokio_hyper_builder(self.pool_idle_timeout));
         let sleep_impl = self.sleep_impl.or_else(default_async_sleep);
         let (connect_timeout, read_timeout) = self
             .connector_settings
@@ -193,9 +223,16 @@ impl<Any> ConnectorBuilder<Any> {
             ),
             None => timeout::HttpReadTimeout::no_timeout(base),
         };
+
+        let proxy_matcher = self
+            .proxy_config
+            .as_ref()
+            .map(|config| config.clone().into_hyper_util_matcher());
+
         Connector {
             adapter: Box::new(Adapter {
                 client: read_timeout,
+                proxy_matcher,
             }),
         }
     }
@@ -281,6 +318,99 @@ impl<Any> ConnectorBuilder<Any> {
         self
     }
 
+    /// Configure proxy settings for this connector
+    ///
+    /// This method allows you to set explicit proxy configuration for the HTTP client.
+    /// The proxy configuration will be used to determine whether requests should be
+    /// routed through a proxy server or connect directly.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # #[cfg(feature = "rustls-aws-lc")]
+    /// # {
+    /// use aws_smithy_http_client::{Connector, proxy::ProxyConfig, tls};
+    ///
+    /// let proxy_config = ProxyConfig::http("http://proxy.example.com:8080")?;
+    /// let connector = Connector::builder()
+    ///     .proxy_config(proxy_config)
+    ///     .tls_provider(tls::Provider::Rustls(tls::rustls_provider::CryptoMode::AwsLc))
+    ///     .build();
+    /// # }
+    /// # Ok::<(), Box<dyn std::error::Error>>(())
+    /// ```
+    pub fn proxy_config(mut self, config: proxy::ProxyConfig) -> Self {
+        self.proxy_config = Some(config);
+        self
+    }
+
+    /// Configure proxy settings for this connector
+    ///
+    /// This is the mutable version of [`proxy_config`](Self::proxy_config).
+    pub fn set_proxy_config(&mut self, config: Option<proxy::ProxyConfig>) -> &mut Self {
+        self.proxy_config = config;
+        self
+    }
+
+    /// Set an optional timeout for idle sockets being kept-alive.
+    ///
+    /// Pass `None` to disable timeout.
+    ///
+    /// Defaults to Hyper's default timeout, which is currently 90 seconds - see
+    /// [hyper_util::client::legacy::Builder::pool_idle_timeout],
+    /// but unlike that function, there is no need to call `pool_timer` yourself.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # #[cfg(feature = "rustls-aws-lc")]
+    /// # {
+    /// use aws_smithy_http_client::{Connector, tls};
+    /// use std::time::Duration;
+    ///
+    /// let connector = Connector::builder()
+    ///     .pool_idle_timeout(Duration::from_secs(30))
+    ///     .tls_provider(tls::Provider::Rustls(tls::rustls_provider::CryptoMode::AwsLc))
+    ///     .build();
+    /// # }
+    /// # Ok::<(), Box<dyn std::error::Error>>(())
+    /// ```
+    pub fn pool_idle_timeout<D>(mut self, val: D) -> Self
+    where
+        D: Into<Option<Duration>>,
+    {
+        self.pool_idle_timeout = Some(val.into());
+        self
+    }
+
+    /// Set an optional timeout for idle sockets being kept-alive.
+    ///
+    /// Pass `None` to use Hyper's default timeout, `Some(None)` to disable timeouts.
+    ///
+    /// This is the mutable version of [`pool_idle_timeout`](Self::pool_idle_timeout).
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # #[cfg(feature = "rustls-aws-lc")]
+    /// # {
+    /// use aws_smithy_http_client::{Connector, tls};
+    /// use std::time::Duration;
+    ///
+    /// let mut connector = Connector::builder();
+    /// connector
+    ///     .set_pool_idle_timeout(Some(Some(Duration::from_secs(30))));
+    /// connector
+    ///     .tls_provider(tls::Provider::Rustls(tls::rustls_provider::CryptoMode::AwsLc))
+    ///     .build();
+    /// # }
+    /// # Ok::<(), Box<dyn std::error::Error>>(())
+    /// ```
+    pub fn set_pool_idle_timeout(&mut self, val: Option<Option<Duration>>) -> &mut Self {
+        self.pool_idle_timeout = val;
+        self
+    }
+
     /// Override the Hyper client [`Builder`](hyper_util::client::legacy::Builder) used to construct this client.
     ///
     /// This enables changing settings like forcing HTTP2 and modifying other default client behavior.
@@ -311,12 +441,14 @@ struct Adapter<C> {
     client: timeout::HttpReadTimeout<
         hyper_util::client::legacy::Client<timeout::ConnectTimeout<C>, SdkBody>,
     >,
+    proxy_matcher: Option<Matcher>,
 }
 
 impl<C> fmt::Debug for Adapter<C> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         f.debug_struct("Adapter")
             .field("client", &"** hyper client **")
+            .field("proxy_matcher", &self.proxy_matcher.is_some())
             .finish()
     }
 }
@@ -347,6 +479,50 @@ fn extract_smithy_connection(capture_conn: &CaptureConnection) -> Option<Connect
     }
 }
 
+fn new_tokio_hyper_builder(
+    pool_idle_timeout: Option<Option<Duration>>,
+) -> hyper_util::client::legacy::Builder {
+    let mut builder = hyper_util::client::legacy::Builder::new(TokioExecutor::new());
+    // Explicitly setting the pool_timer is required for connection timeouts to work.
+    builder.pool_timer(TokioTimer::new());
+
+    if let Some(pool_idle_timeout) = pool_idle_timeout {
+        builder.pool_idle_timeout(pool_idle_timeout);
+    }
+
+    builder
+}
+
+impl<C> Adapter<C> {
+    /// Add proxy authentication header to the request if needed
+    fn add_proxy_auth_header(&self, request: &mut http_1x::Request<SdkBody>) {
+        // Only add auth for HTTP requests (not HTTPS which uses CONNECT tunneling)
+        if request.uri().scheme() != Some(&http_1x::uri::Scheme::HTTP) {
+            return;
+        }
+
+        // Don't override existing proxy authorization header
+        if request
+            .headers()
+            .contains_key(http_1x::header::PROXY_AUTHORIZATION)
+        {
+            return;
+        }
+
+        if let Some(ref matcher) = self.proxy_matcher {
+            if let Some(intercept) = matcher.intercept(request.uri()) {
+                // Add basic auth header if available
+                if let Some(auth_header) = intercept.basic_auth() {
+                    request
+                        .headers_mut()
+                        .insert(http_1x::header::PROXY_AUTHORIZATION, auth_header.clone());
+                    tracing::debug!("added proxy authentication header for {}", request.uri());
+                }
+            }
+        }
+    }
+}
+
 impl<C> HttpConnector for Adapter<C>
 where
     C: Clone + Send + Sync + 'static,
@@ -363,6 +539,9 @@ where
                 return HttpConnectorFuture::ready(Err(ConnectorError::user(err.into())));
             }
         };
+
+        self.add_proxy_auth_header(&mut request);
+
         let capture_connection = capture_connection(&mut request);
         if let Some(capture_smithy_connection) =
             request.extensions().get::<CaptureSmithyConnection>()
@@ -565,6 +744,7 @@ where
 #[derive(Clone, Default, Debug)]
 pub struct Builder<Tls = TlsUnset> {
     client_builder: Option<hyper_util::client::legacy::Builder>,
+    pool_idle_timeout: Option<Option<Duration>>,
     #[allow(unused)]
     tls_provider: Tls,
 }
@@ -614,16 +794,27 @@ cfg_tls! {
                     feature = "rustls-ring"
                 ))]
                 tls::Provider::Rustls(crypto_mode) => {
+                    let proxy_config = self.proxy_config.clone()
+                        .unwrap_or_else(proxy::ProxyConfig::disabled);
+
                     let https_connector = tls::rustls_provider::build_connector::wrap_connector(
                         http_connector,
                         crypto_mode.clone(),
                         &self.tls.context,
+                        proxy_config,
                     );
                     self.wrap_connector(https_connector)
                 },
                 #[cfg(feature = "s2n-tls")]
                 tls::Provider::S2nTls  => {
-                    let https_connector = tls::s2n_tls_provider::build_connector::wrap_connector(http_connector, &self.tls.context);
+                    let proxy_config = self.proxy_config.clone()
+                        .unwrap_or_else(proxy::ProxyConfig::disabled);
+
+                    let https_connector = tls::s2n_tls_provider::build_connector::wrap_connector(
+                        http_connector,
+                        &self.tls.context,
+                        proxy_config,
+                    );
                     self.wrap_connector(https_connector)
                 }
             }
@@ -638,6 +829,7 @@ cfg_tls! {
         pub fn build_https(self) -> SharedHttpClient {
             build_with_conn_fn(
                 self.client_builder,
+                self.pool_idle_timeout,
                 move |client_builder, settings, runtime_components| {
                     let builder = new_conn_builder(client_builder, settings, runtime_components)
                         .tls_provider(self.tls_provider.provider.clone())
@@ -654,6 +846,7 @@ cfg_tls! {
         ) -> SharedHttpClient {
             build_with_conn_fn(
                 self.client_builder,
+                self.pool_idle_timeout,
                 move |client_builder, settings, runtime_components| {
                     let builder = new_conn_builder(client_builder, settings, runtime_components)
                         .tls_provider(self.tls_provider.provider.clone())
@@ -671,17 +864,96 @@ cfg_tls! {
     }
 }
 
+impl<Any> Builder<Any> {
+    /// Set an optional timeout for idle sockets being kept-alive.
+    ///
+    /// Pass `None` to disable timeout.
+    ///
+    /// Defaults to Hyper's default timeout, which is currently 90 seconds - see
+    /// [hyper_util::client::legacy::Builder::pool_idle_timeout],
+    /// but unlike that function, there is no need to call `pool_timer` yourself.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # #[cfg(feature = "rustls-aws-lc")]
+    /// # {
+    /// use aws_smithy_http_client::{Builder, tls};
+    /// use std::time::Duration;
+    ///
+    /// let client = Builder::new()
+    ///     .pool_idle_timeout(Duration::from_secs(30))
+    ///     .tls_provider(tls::Provider::Rustls(tls::rustls_provider::CryptoMode::AwsLc))
+    ///     .build_https();
+    /// # }
+    /// # Ok::<(), Box<dyn std::error::Error>>(())
+    /// ```
+    pub fn pool_idle_timeout<D>(mut self, val: D) -> Self
+    where
+        D: Into<Option<Duration>>,
+    {
+        self.pool_idle_timeout = Some(val.into());
+        self
+    }
+
+    /// Set an optional timeout for idle sockets being kept-alive.
+    ///
+    /// Pass `None` to use Hyper's default timeout, `Some(None)` to disable timeouts.
+    ///
+    /// This is the mutable version of [`pool_idle_timeout`](Self::pool_idle_timeout).
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # #[cfg(feature = "rustls-aws-lc")]
+    /// # {
+    /// use std::time::Duration;
+    /// use aws_smithy_http_client::{Builder, tls};
+    ///
+    /// let mut client = Builder::new();
+    /// client.set_pool_idle_timeout(Some(Some(Duration::from_secs(30))));
+    /// client
+    ///     .tls_provider(tls::Provider::Rustls(tls::rustls_provider::CryptoMode::AwsLc))
+    ///     .build_https();
+    /// # }
+    /// # Ok::<(), Box<dyn std::error::Error>>(())
+    /// ```
+    pub fn set_pool_idle_timeout(&mut self, val: Option<Option<Duration>>) -> &mut Self {
+        self.pool_idle_timeout = val;
+        self
+    }
+}
+
 impl Builder<TlsUnset> {
     /// Creates a new builder.
     pub fn new() -> Self {
         Self::default()
     }
 
+    /// Returns a [`SharedHttpClient`] that calls the given `connector` function to select an HTTP(S) connector.
+    #[doc(hidden)]
+    pub fn build_with_connector_fn<F>(self, connector_fn: F) -> SharedHttpClient
+    where
+        F: Fn(Option<&HttpConnectorSettings>, Option<&RuntimeComponents>) -> Connector
+            + Send
+            + Sync
+            + 'static,
+    {
+        build_with_conn_fn(
+            self.client_builder,
+            self.pool_idle_timeout,
+            move |_builder, settings, runtime_components| {
+                connector_fn(settings, runtime_components)
+            },
+        )
+    }
+
     /// Build a new HTTP client without TLS enabled
     #[doc(hidden)]
     pub fn build_http(self) -> SharedHttpClient {
         build_with_conn_fn(
             self.client_builder,
+            self.pool_idle_timeout,
             move |client_builder, settings, runtime_components| {
                 let builder = new_conn_builder(client_builder, settings, runtime_components);
                 builder.build_http()
@@ -693,6 +965,7 @@ impl Builder<TlsUnset> {
     pub fn tls_provider(self, provider: tls::Provider) -> Builder<TlsProviderSelected> {
         Builder {
             client_builder: self.client_builder,
+            pool_idle_timeout: self.pool_idle_timeout,
             tls_provider: TlsProviderSelected {
                 provider,
                 context: TlsContext::default(),
@@ -703,6 +976,7 @@ impl Builder<TlsUnset> {
 
 pub(crate) fn build_with_conn_fn<F>(
     client_builder: Option<hyper_util::client::legacy::Builder>,
+    pool_idle_timeout: Option<Option<Duration>>,
     connector_fn: F,
 ) -> SharedHttpClient
 where
@@ -715,10 +989,11 @@ where
         + Sync
         + 'static,
 {
+    let client_builder =
+        client_builder.unwrap_or_else(|| new_tokio_hyper_builder(pool_idle_timeout));
     SharedHttpClient::new(HyperClient {
         connector_cache: RwLock::new(HashMap::new()),
-        client_builder: client_builder
-            .unwrap_or_else(|| hyper_util::client::legacy::Builder::new(TokioExecutor::new())),
+        client_builder,
         connector_fn,
     })
 }
@@ -726,6 +1001,7 @@ where
 #[allow(dead_code)]
 pub(crate) fn build_with_tcp_conn_fn<C, F>(
     client_builder: Option<hyper_util::client::legacy::Builder>,
+    pool_idle_timeout: Option<Option<Duration>>,
     tcp_connector_fn: F,
 ) -> SharedHttpClient
 where
@@ -739,6 +1015,7 @@ where
 {
     build_with_conn_fn(
         client_builder,
+        pool_idle_timeout,
         move |client_builder, settings, runtime_components| {
             let builder = new_conn_builder(client_builder, settings, runtime_components);
             builder.wrap_connector(tcp_connector_fn())
@@ -782,7 +1059,7 @@ mod test {
     async fn connector_selection() {
         // Create a client that increments a count every time it creates a new Connector
         let creation_count = Arc::new(AtomicU32::new(0));
-        let http_client = build_with_tcp_conn_fn(None, {
+        let http_client = build_with_tcp_conn_fn(None, None, {
             let count = creation_count.clone();
             move || {
                 count.fetch_add(1, Ordering::Relaxed);
@@ -993,7 +1270,7 @@ mod test {
             .build();
 
         let resolver = HyperUtilResolver {
-            resolver: TestResolver::default(),
+            resolver: TestResolver,
         };
         let connector = Connector::builder().base_connector_with_resolver(resolver);
 
