@@ -116,40 +116,40 @@ async fn refresh_task<T>(
 {
     loop {
         let token_result = token_provider.token().await;
-        let result = token_result.clone().map(|token| {
+        let expiry = token_result.as_ref().ok().map(|t| t.expires_at);
+        let tagged = token_result.map(|token| {
             let entity_tag = EntityTag::new();
             (token, entity_tag)
         });
 
-        let _ = tx_token.send(Some(result));
+        let _ = tx_token.send(Some(tagged));
 
-        match token_result {
-            Ok(new_token) => {
-                if let Some(expiry) = new_token.expires_at {
-                    let time_until_expiry = expiry.checked_duration_since(Instant::now());
+        match expiry {
+            Some(Some(expiry)) => {
+                let time_until_expiry = expiry.checked_duration_since(Instant::now());
 
-                    match time_until_expiry {
-                        None => {
-                            // We were given a token that is expired, or expires in less than 10 seconds.
-                            // We will immediately restart the loop, and fetch a new token.
-                        }
-                        Some(time_until_expiry) => {
-                            if time_until_expiry > NORMAL_REFRESH_SLACK {
-                                sleep(time_until_expiry - NORMAL_REFRESH_SLACK).await;
-                            } else if time_until_expiry > SHORT_REFRESH_SLACK {
-                                // If expiry is less than 4 mins, try to refresh every 10 seconds
-                                // This is to handle cases where MDS **repeatedly** returns about to expire tokens.
-                                sleep(SHORT_REFRESH_SLACK).await;
-                            }
+                match time_until_expiry {
+                    None => {
+                        // We were given a token that is expired, or expires in less than 10 seconds.
+                        // We will immediately restart the loop, and fetch a new token.
+                    }
+                    Some(time_until_expiry) => {
+                        if time_until_expiry > NORMAL_REFRESH_SLACK {
+                            sleep(time_until_expiry - NORMAL_REFRESH_SLACK).await;
+                        } else if time_until_expiry > SHORT_REFRESH_SLACK {
+                            // If expiry is less than 4 mins, try to refresh every 10 seconds
+                            // This is to handle cases where MDS **repeatedly** returns about to expire tokens.
+                            sleep(SHORT_REFRESH_SLACK).await;
                         }
                     }
-                } else {
-                    // If there is no expiry, the token is valid forever, so no need to refresh
-                    // TODO(#1553): Validate that all auth backends provide expiry and make expiry not optional.
-                    break;
                 }
             }
-            Err(_) => {
+            Some(None) => {
+                // If there is no expiry, the token is valid forever, so no need to refresh
+                // TODO(#1553): Validate that all auth backends provide expiry and make expiry not optional.
+                break;
+            }
+            None => {
                 // The retry policy has been used already by the inner token provider.
                 // If it ended in an error, just quit the background task.
                 break;
