@@ -32,18 +32,19 @@ use std::time::Duration;
 
 use base64::Engine;
 use futures_util::io::{BufReader, BufWriter};
-use jsonrpsee_core::client::{MaybeSend, ReceivedMessage, TransportReceiverT, TransportSenderT};
+use jsonrpsee_core::Cow;
 use jsonrpsee_core::TEN_MB_SIZE_BYTES;
-use jsonrpsee_core::{async_trait, Cow};
+use jsonrpsee_core::client::{ReceivedMessage, TransportReceiverT, TransportSenderT};
+use soketto::connection::CloseReason;
 use soketto::connection::Error::Utf8;
 use soketto::data::ByteSlice125;
 use soketto::handshake::client::{Client as WsHandshakeClient, ServerResponse};
-use soketto::{connection, Data, Incoming};
+use soketto::{Data, Incoming, connection};
 use thiserror::Error;
 use tokio::net::TcpStream;
 use tokio_util::compat::{Compat, TokioAsyncReadCompatExt};
 
-pub use http::{uri::InvalidUri, HeaderMap, HeaderValue, Uri};
+pub use http::{HeaderMap, HeaderValue, Uri, uri::InvalidUri};
 pub use soketto::handshake::client::Header;
 pub use stream::EitherStream;
 pub use tokio::io::{AsyncRead, AsyncWrite};
@@ -94,6 +95,8 @@ pub struct WsTransportClientBuilder {
 	pub max_request_size: u32,
 	/// Max response payload size
 	pub max_response_size: u32,
+	/// Max frame size
+	pub max_frame_size: Option<u32>,
 	/// Max number of redirections.
 	pub max_redirections: usize,
 	/// TCP no delay.
@@ -107,6 +110,7 @@ impl Default for WsTransportClientBuilder {
 			certificate_store: CertificateStore::Native,
 			max_request_size: TEN_MB_SIZE_BYTES,
 			max_response_size: TEN_MB_SIZE_BYTES,
+			max_frame_size: None,
 			connection_timeout: Duration::from_secs(10),
 			headers: http::HeaderMap::new(),
 			max_redirections: 5,
@@ -139,6 +143,12 @@ impl WsTransportClientBuilder {
 		self
 	}
 
+	/// Set the maximum size of a frame in bytes (default is none).
+	pub fn max_frame_size(mut self, size: u32) -> Self {
+		self.max_frame_size = Some(size);
+		self
+	}
+
 	/// Set connection timeout for the handshake (default is 10 seconds).
 	pub fn connection_timeout(mut self, timeout: Duration) -> Self {
 		self.connection_timeout = timeout;
@@ -230,68 +240,72 @@ pub enum WsError {
 	/// Message was too large.
 	#[error("The message was too large")]
 	MessageTooLarge,
+	/// Connection was closed.
+	#[error("Connection was closed: {0:?}")]
+	Closed(CloseReason),
 }
 
-#[async_trait]
 impl<T> TransportSenderT for Sender<T>
 where
-	T: futures_util::io::AsyncRead + futures_util::io::AsyncWrite + Unpin + MaybeSend + 'static,
+	T: futures_util::io::AsyncRead + futures_util::io::AsyncWrite + Send + Unpin + 'static,
 {
 	type Error = WsError;
 
 	/// Sends out a request. Returns a `Future` that finishes when the request has been
 	/// successfully sent.
-	async fn send(&mut self, body: String) -> Result<(), Self::Error> {
-		if body.len() > self.max_request_size as usize {
-			return Err(WsError::MessageTooLarge);
-		}
+	fn send(&mut self, body: String) -> impl Future<Output = Result<(), Self::Error>> + Send {
+		async {
+			if body.len() > self.max_request_size as usize {
+				return Err(WsError::MessageTooLarge);
+			}
 
-		self.inner.send_text(body).await?;
-		self.inner.flush().await?;
-		Ok(())
+			self.inner.send_text(body).await?;
+			self.inner.flush().await?;
+			Ok(())
+		}
 	}
 
 	/// Sends out a ping request. Returns a `Future` that finishes when the request has been
 	/// successfully sent.
-	async fn send_ping(&mut self) -> Result<(), Self::Error> {
-		tracing::debug!(target: LOG_TARGET, "Send ping");
-		// Submit empty slice as "optional" parameter.
-		let slice: &[u8] = &[];
-		// Byte slice fails if the provided slice is larger than 125 bytes.
-		let byte_slice = ByteSlice125::try_from(slice).expect("Empty slice should fit into ByteSlice125");
+	fn send_ping(&mut self) -> impl Future<Output = Result<(), Self::Error>> + Send {
+		async {
+			tracing::debug!(target: LOG_TARGET, "Send ping");
+			// Submit empty slice as "optional" parameter.
+			let slice: &[u8] = &[];
+			// Byte slice fails if the provided slice is larger than 125 bytes.
+			let byte_slice = ByteSlice125::try_from(slice).expect("Empty slice should fit into ByteSlice125");
 
-		self.inner.send_ping(byte_slice).await?;
-		self.inner.flush().await?;
-		Ok(())
+			self.inner.send_ping(byte_slice).await?;
+			self.inner.flush().await?;
+			Ok(())
+		}
 	}
 
 	/// Send a close message and close the connection.
-	async fn close(&mut self) -> Result<(), WsError> {
-		self.inner.close().await.map_err(Into::into)
+	fn close(&mut self) -> impl Future<Output = Result<(), WsError>> + Send {
+		async { self.inner.close().await.map_err(Into::into) }
 	}
 }
 
-#[async_trait]
 impl<T> TransportReceiverT for Receiver<T>
 where
-	T: futures_util::io::AsyncRead + futures_util::io::AsyncWrite + Unpin + MaybeSend + 'static,
+	T: futures_util::io::AsyncRead + futures_util::io::AsyncWrite + Unpin + Send + 'static,
 {
 	type Error = WsError;
 
 	/// Returns a `Future` resolving when the server sent us something back.
-	async fn receive(&mut self) -> Result<ReceivedMessage, Self::Error> {
-		loop {
+	fn receive(&mut self) -> impl Future<Output = Result<ReceivedMessage, Self::Error>> + Send {
+		async {
 			let mut message = Vec::new();
-			let recv = self.inner.receive(&mut message).await?;
 
-			match recv {
+			match self.inner.receive(&mut message).await? {
 				Incoming::Data(Data::Text(_)) => {
 					let s = String::from_utf8(message).map_err(|err| WsError::Connection(Utf8(err.utf8_error())))?;
-					break Ok(ReceivedMessage::Text(s));
+					Ok(ReceivedMessage::Text(s))
 				}
-				Incoming::Data(Data::Binary(_)) => break Ok(ReceivedMessage::Bytes(message)),
-				Incoming::Pong(_) => break Ok(ReceivedMessage::Pong),
-				_ => continue,
+				Incoming::Data(Data::Binary(_)) => Ok(ReceivedMessage::Bytes(message)),
+				Incoming::Pong(_) => Ok(ReceivedMessage::Pong),
+				Incoming::Closed(c) => Err(WsError::Closed(c)),
 			}
 		}
 	}
@@ -427,7 +441,9 @@ impl WsTransportClientBuilder {
 									match target.path_and_query.rfind('/') {
 										Some(offset) => target.path_and_query.replace_range(offset + 1.., &location),
 										None => {
-											let e = format!("path_and_query: {location}; this is a bug it must contain `/` please open issue");
+											let e = format!(
+												"path_and_query: {location}; this is a bug it must contain `/` please open issue"
+											);
 											err = Some(Err(WsHandshakeError::Url(e.into())));
 											continue;
 										}
@@ -491,6 +507,10 @@ impl WsTransportClientBuilder {
 				tracing::debug!(target: LOG_TARGET, "Connection established to target: {:?}", target);
 				let mut builder = client.into_builder();
 				builder.set_max_message_size(self.max_response_size as usize);
+				// Use the max frame size if any, otherwise let the underlying code use appropriate defaults.
+				if let Some(max_frame_size) = self.max_frame_size {
+					builder.set_max_frame_size(max_frame_size as usize);
+				}
 				let (sender, receiver) = builder.finish();
 				Ok((Sender { inner: sender, max_request_size: self.max_request_size }, Receiver { inner: receiver }))
 			}
