@@ -24,17 +24,17 @@
 // IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-use crate::types::error::{ErrorCode, ErrorObject};
 use crate::WsClientBuilder;
+use crate::types::error::{ErrorCode, ErrorObject};
 
 use jsonrpsee_core::client::{
 	BatchResponse, ClientT, Error, IdKind, Subscription, SubscriptionClientT, SubscriptionCloseReason,
 };
 use jsonrpsee_core::params::BatchRequestBuilder;
-use jsonrpsee_core::{rpc_params, DeserializeOwned};
+use jsonrpsee_core::{DeserializeOwned, rpc_params};
+use jsonrpsee_test_utils::TimeoutFutureExt;
 use jsonrpsee_test_utils::helpers::*;
 use jsonrpsee_test_utils::mocks::{Id, WebSocketTestServer};
-use jsonrpsee_test_utils::TimeoutFutureExt;
 use jsonrpsee_types::error::ErrorObjectOwned;
 use jsonrpsee_types::{Notification, SubscriptionId, SubscriptionPayload, SubscriptionResponse};
 use serde_json::Value as JsonValue;
@@ -359,16 +359,10 @@ async fn batch_request_with_failed_call_works() {
 	assert_eq!(res.len(), 3);
 
 	let successful_calls: Vec<_> = res.iter().filter_map(|r| r.as_ref().ok()).collect();
-	let failed_calls: Vec<_> = res
-		.iter()
-		.filter_map(|r| match r {
-			Err(e) => Some(e),
-			_ => None,
-		})
-		.collect();
+	let failed_calls: Vec<_> = res.iter().filter_map(|r| r.clone().err()).collect();
 
 	assert_eq!(successful_calls, vec!["hello", "here's your swag"]);
-	assert_eq!(failed_calls, vec![&ErrorObject::from(ErrorCode::MethodNotFound)]);
+	assert_eq!(failed_calls, vec![ErrorObject::from(ErrorCode::MethodNotFound)]);
 }
 
 #[tokio::test]
