@@ -443,6 +443,7 @@ impl<'w, 'k, W: Write> Struct<'w, 'k, W> {
             indent: self.ser.ser.indent.borrow(),
             // If previous field does not require indent, do not write it
             write_indent: self.write_indent,
+            text_format: self.ser.ser.text_format,
             allow_primitive: true,
             expand_empty_elements: self.ser.ser.expand_empty_elements,
         };
@@ -550,7 +551,7 @@ impl<'w, 'k, W: Write> SerializeMap for Map<'w, 'k, W> {
     where
         T: ?Sized + Serialize,
     {
-        if let Some(_) = self.key.take() {
+        if self.key.take().is_some() {
             return Err(SeError::Custom(
                 "calling `serialize_key` twice without `serialize_value`".to_string(),
             ));
@@ -596,7 +597,7 @@ impl<'w, 'k, W: Write> SerializeMap for Map<'w, 'k, W> {
 mod tests {
     use super::*;
     use crate::se::content::tests::*;
-    use crate::se::{Indent, QuoteLevel};
+    use crate::se::{Indent, QuoteLevel, TextFormat};
     use crate::utils::Bytes;
     use serde::Serialize;
     use std::collections::BTreeMap;
@@ -635,6 +636,7 @@ mod tests {
                             level: QuoteLevel::Full,
                             indent: Indent::None,
                             write_indent: false,
+                            text_format: TextFormat::Text,
                             allow_primitive: true,
                             expand_empty_elements: false,
                         },
@@ -661,6 +663,7 @@ mod tests {
                             level: QuoteLevel::Full,
                             indent: Indent::None,
                             write_indent: false,
+                            text_format: TextFormat::Text,
                             allow_primitive: true,
                             expand_empty_elements: false,
                         },
@@ -689,13 +692,13 @@ mod tests {
         serialize_as!(i16_:   -4200i16             => "<root>-4200</root>");
         serialize_as!(i32_:   -42000000i32         => "<root>-42000000</root>");
         serialize_as!(i64_:   -42000000000000i64   => "<root>-42000000000000</root>");
-        serialize_as!(isize_: -42000000000000isize => "<root>-42000000000000</root>");
+        serialize_as!(isize_: -42000000isize       => "<root>-42000000</root>");
 
         serialize_as!(u8_:    42u8                => "<root>42</root>");
         serialize_as!(u16_:   4200u16             => "<root>4200</root>");
         serialize_as!(u32_:   42000000u32         => "<root>42000000</root>");
         serialize_as!(u64_:   42000000000000u64   => "<root>42000000000000</root>");
-        serialize_as!(usize_: 42000000000000usize => "<root>42000000000000</root>");
+        serialize_as!(usize_: 42000000usize       => "<root>42000000</root>");
 
         serde_if_integer128! {
             serialize_as!(i128_: -420000000000000000000000000000i128 => "<root>-420000000000000000000000000000</root>");
@@ -791,13 +794,13 @@ mod tests {
                 text!(i16_:   -4200i16             => "-4200");
                 text!(i32_:   -42000000i32         => "-42000000");
                 text!(i64_:   -42000000000000i64   => "-42000000000000");
-                text!(isize_: -42000000000000isize => "-42000000000000");
+                text!(isize_: -42000000isize       => "-42000000");
 
                 text!(u8_:    42u8                => "42");
                 text!(u16_:   4200u16             => "4200");
                 text!(u32_:   42000000u32         => "42000000");
                 text!(u64_:   42000000000000u64   => "42000000000000");
-                text!(usize_: 42000000000000usize => "42000000000000");
+                text!(usize_: 42000000usize       => "42000000");
 
                 serde_if_integer128! {
                     text!(i128_: -420000000000000000000000000000i128 => "-420000000000000000000000000000");
@@ -916,13 +919,13 @@ mod tests {
                 text!(i16_:   -4200i16             => "-4200");
                 text!(i32_:   -42000000i32         => "-42000000");
                 text!(i64_:   -42000000000000i64   => "-42000000000000");
-                text!(isize_: -42000000000000isize => "-42000000000000");
+                text!(isize_: -42000000isize       => "-42000000");
 
                 text!(u8_:    42u8                => "42");
                 text!(u16_:   4200u16             => "4200");
                 text!(u32_:   42000000u32         => "42000000");
                 text!(u64_:   42000000000000u64   => "42000000000000");
-                text!(usize_: 42000000000000usize => "42000000000000");
+                text!(usize_: 42000000usize       => "42000000");
 
                 serde_if_integer128! {
                     text!(i128_: -420000000000000000000000000000i128 => "-420000000000000000000000000000");
@@ -1045,13 +1048,13 @@ mod tests {
                 value!(i16_:   -4200i16             => "-4200");
                 value!(i32_:   -42000000i32         => "-42000000");
                 value!(i64_:   -42000000000000i64   => "-42000000000000");
-                value!(isize_: -42000000000000isize => "-42000000000000");
+                value!(isize_: -42000000isize       => "-42000000");
 
                 value!(u8_:    42u8                => "42");
                 value!(u16_:   4200u16             => "4200");
                 value!(u32_:   42000000u32         => "42000000");
                 value!(u64_:   42000000000000u64   => "42000000000000");
-                value!(usize_: 42000000000000usize => "42000000000000");
+                value!(usize_: 42000000usize       => "42000000");
 
                 serde_if_integer128! {
                     value!(i128_: -420000000000000000000000000000i128 => "-420000000000000000000000000000");
@@ -1156,13 +1159,13 @@ mod tests {
                 value!(i16_:   -4200i16             => "-4200");
                 value!(i32_:   -42000000i32         => "-42000000");
                 value!(i64_:   -42000000000000i64   => "-42000000000000");
-                value!(isize_: -42000000000000isize => "-42000000000000");
+                value!(isize_: -42000000isize       => "-42000000");
 
                 value!(u8_:    42u8                => "42");
                 value!(u16_:   4200u16             => "4200");
                 value!(u32_:   42000000u32         => "42000000");
                 value!(u64_:   42000000000000u64   => "42000000000000");
-                value!(usize_: 42000000000000usize => "42000000000000");
+                value!(usize_: 42000000usize       => "42000000");
 
                 serde_if_integer128! {
                     value!(i128_: -420000000000000000000000000000i128 => "-420000000000000000000000000000");
@@ -1356,6 +1359,7 @@ mod tests {
                             level: QuoteLevel::Full,
                             indent: Indent::Owned(Indentation::new(b' ', 2)),
                             write_indent: false,
+                            text_format: TextFormat::Text,
                             allow_primitive: true,
                             expand_empty_elements: false,
                         },
@@ -1382,6 +1386,7 @@ mod tests {
                             level: QuoteLevel::Full,
                             indent: Indent::Owned(Indentation::new(b' ', 2)),
                             write_indent: false,
+                            text_format: TextFormat::Text,
                             allow_primitive: true,
                             expand_empty_elements: false,
                         },
@@ -1410,13 +1415,13 @@ mod tests {
         serialize_as!(i16_:   -4200i16             => "<root>-4200</root>");
         serialize_as!(i32_:   -42000000i32         => "<root>-42000000</root>");
         serialize_as!(i64_:   -42000000000000i64   => "<root>-42000000000000</root>");
-        serialize_as!(isize_: -42000000000000isize => "<root>-42000000000000</root>");
+        serialize_as!(isize_: -42000000isize       => "<root>-42000000</root>");
 
         serialize_as!(u8_:    42u8                => "<root>42</root>");
         serialize_as!(u16_:   4200u16             => "<root>4200</root>");
         serialize_as!(u32_:   42000000u32         => "<root>42000000</root>");
         serialize_as!(u64_:   42000000000000u64   => "<root>42000000000000</root>");
-        serialize_as!(usize_: 42000000000000usize => "<root>42000000000000</root>");
+        serialize_as!(usize_: 42000000usize       => "<root>42000000</root>");
 
         serde_if_integer128! {
             serialize_as!(i128_: -420000000000000000000000000000i128 => "<root>-420000000000000000000000000000</root>");
@@ -1515,13 +1520,13 @@ mod tests {
                 text!(i16_:   -4200i16             => "-4200");
                 text!(i32_:   -42000000i32         => "-42000000");
                 text!(i64_:   -42000000000000i64   => "-42000000000000");
-                text!(isize_: -42000000000000isize => "-42000000000000");
+                text!(isize_: -42000000isize       => "-42000000");
 
                 text!(u8_:    42u8                => "42");
                 text!(u16_:   4200u16             => "4200");
                 text!(u32_:   42000000u32         => "42000000");
                 text!(u64_:   42000000000000u64   => "42000000000000");
-                text!(usize_: 42000000000000usize => "42000000000000");
+                text!(usize_: 42000000usize       => "42000000");
 
                 serde_if_integer128! {
                     text!(i128_: -420000000000000000000000000000i128 => "-420000000000000000000000000000");
@@ -1641,13 +1646,13 @@ mod tests {
                 text!(i16_:   -4200i16             => "-4200");
                 text!(i32_:   -42000000i32         => "-42000000");
                 text!(i64_:   -42000000000000i64   => "-42000000000000");
-                text!(isize_: -42000000000000isize => "-42000000000000");
+                text!(isize_: -42000000isize       => "-42000000");
 
                 text!(u8_:    42u8                => "42");
                 text!(u16_:   4200u16             => "4200");
                 text!(u32_:   42000000u32         => "42000000");
                 text!(u64_:   42000000000000u64   => "42000000000000");
-                text!(usize_: 42000000000000usize => "42000000000000");
+                text!(usize_: 42000000usize       => "42000000");
 
                 serde_if_integer128! {
                     text!(i128_: -420000000000000000000000000000i128 => "-420000000000000000000000000000");
@@ -1772,13 +1777,13 @@ mod tests {
                 value!(i16_:   -4200i16             => "-4200");
                 value!(i32_:   -42000000i32         => "-42000000");
                 value!(i64_:   -42000000000000i64   => "-42000000000000");
-                value!(isize_: -42000000000000isize => "-42000000000000");
+                value!(isize_: -42000000isize       => "-42000000");
 
                 value!(u8_:    42u8                => "42");
                 value!(u16_:   4200u16             => "4200");
                 value!(u32_:   42000000u32         => "42000000");
                 value!(u64_:   42000000000000u64   => "42000000000000");
-                value!(usize_: 42000000000000usize => "42000000000000");
+                value!(usize_: 42000000usize       => "42000000");
 
                 serde_if_integer128! {
                     value!(i128_: -420000000000000000000000000000i128 => "-420000000000000000000000000000");
@@ -1886,13 +1891,13 @@ mod tests {
                 value!(i16_:   -4200i16             => "-4200");
                 value!(i32_:   -42000000i32         => "-42000000");
                 value!(i64_:   -42000000000000i64   => "-42000000000000");
-                value!(isize_: -42000000000000isize => "-42000000000000");
+                value!(isize_: -42000000isize       => "-42000000");
 
                 value!(u8_:    42u8                => "42");
                 value!(u16_:   4200u16             => "4200");
                 value!(u32_:   42000000u32         => "42000000");
                 value!(u64_:   42000000000000u64   => "42000000000000");
-                value!(usize_: 42000000000000usize => "42000000000000");
+                value!(usize_: 42000000usize       => "42000000");
 
                 serde_if_integer128! {
                     value!(i128_: -420000000000000000000000000000i128 => "-420000000000000000000000000000");
@@ -2099,6 +2104,7 @@ mod tests {
                             level: QuoteLevel::Full,
                             indent: Indent::None,
                             write_indent: false,
+                            text_format: TextFormat::Text,
                             allow_primitive: true,
                             expand_empty_elements: true,
                         },
