@@ -441,7 +441,12 @@ pub async fn link_package(
                 path_type: entry.path_type.into(),
                 no_link: entry.no_link,
                 sha256: entry.sha256,
-                sha256_in_prefix: Some(result.sha256),
+                // Only set sha256_in_prefix if it differs from the original sha256
+                sha256_in_prefix: if Some(result.sha256) == entry.sha256 {
+                    None
+                } else {
+                    Some(result.sha256)
+                },
                 size_in_bytes: Some(result.file_size),
                 file_mode: match result.method {
                     LinkMethod::Patched(file_mode) => Some(file_mode),
@@ -857,7 +862,12 @@ pub fn link_package_sync(
                     path_type: entry.path_type.into(),
                     no_link: entry.no_link,
                     sha256: entry.sha256,
-                    sha256_in_prefix: Some(result.sha256),
+                    // Only set sha256_in_prefix if it differs from the original sha256
+                    sha256_in_prefix: if Some(result.sha256) == entry.sha256 {
+                        None
+                    } else {
+                        Some(result.sha256)
+                    },
                     size_in_bytes: Some(result.file_size),
                     file_mode: match result.method {
                         LinkMethod::Patched(file_mode) => Some(file_mode),
