@@ -11,10 +11,10 @@ use crate::user::privs::*;
 /// Return type: `u32`.
 pub struct GetCalendarBorder {}
 
-impl MsgSend for GetCalendarBorder {
+unsafe impl MsgSend for GetCalendarBorder {
 	type RetType = u32;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		v as _
 	}
 
@@ -33,10 +33,10 @@ impl MsgSend for GetCalendarBorder {
 /// Return type: `u32`.
 pub struct GetCalendarCount {}
 
-impl MsgSend for GetCalendarCount {
+unsafe impl MsgSend for GetCalendarCount {
 	type RetType = u32;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		v as _
 	}
 
@@ -57,10 +57,10 @@ pub struct GetCalendarGridInfo<'a, 'b> {
 	pub info: &'b mut MCGRIDINFO<'a>,
 }
 
-impl<'a, 'b> MsgSend for GetCalendarGridInfo<'a, 'b> {
+unsafe impl<'a, 'b> MsgSend for GetCalendarGridInfo<'a, 'b> {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -79,11 +79,11 @@ impl<'a, 'b> MsgSend for GetCalendarGridInfo<'a, 'b> {
 /// Return type: `co::CAL`.
 pub struct GetCalId {}
 
-impl MsgSend for GetCalId {
+unsafe impl MsgSend for GetCalId {
 	type RetType = co::CAL;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
-		co::CAL::from_raw(v as _)
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		unsafe { co::CAL::from_raw(v as _) }
 	}
 
 	fn as_generic_wm(&mut self) -> WndMsg {
@@ -103,11 +103,11 @@ pub struct GetColor {
 	pub which: co::MCSC,
 }
 
-impl MsgSend for GetColor {
+unsafe impl MsgSend for GetColor {
 	type RetType = SysResult<COLORREF>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
-		minus1_as_badargs(v).map(|v| COLORREF::from_raw(v as _))
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		minus1_as_badargs(v).map(|v| unsafe { COLORREF::from_raw(v as _) })
 	}
 
 	fn as_generic_wm(&mut self) -> WndMsg {
@@ -125,11 +125,11 @@ impl MsgSend for GetColor {
 /// Return type: `co::MCMV`.
 pub struct GetCurrentView {}
 
-impl MsgSend for GetCurrentView {
+unsafe impl MsgSend for GetCurrentView {
 	type RetType = co::MCMV;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
-		co::MCMV::from_raw(v as _)
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		unsafe { co::MCMV::from_raw(v as _) }
 	}
 
 	fn as_generic_wm(&mut self) -> WndMsg {
@@ -149,10 +149,10 @@ pub struct GetCurSel<'a> {
 	pub info: &'a mut SYSTEMTIME,
 }
 
-impl<'a> MsgSend for GetCurSel<'a> {
+unsafe impl<'a> MsgSend for GetCurSel<'a> {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -171,10 +171,10 @@ impl<'a> MsgSend for GetCurSel<'a> {
 /// Return type: `(bool, u16)`.
 pub struct GetFirstDayOfWeek {}
 
-impl MsgSend for GetFirstDayOfWeek {
+unsafe impl MsgSend for GetFirstDayOfWeek {
 	type RetType = (bool, u16);
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		(HIWORD(v as _) != 0, LOWORD(v as _))
 	}
 
@@ -193,10 +193,10 @@ impl MsgSend for GetFirstDayOfWeek {
 /// Return type: `u32`.
 pub struct GetMaxSelCount {}
 
-impl MsgSend for GetMaxSelCount {
+unsafe impl MsgSend for GetMaxSelCount {
 	type RetType = u32;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		v as _
 	}
 
@@ -215,10 +215,10 @@ impl MsgSend for GetMaxSelCount {
 /// Return type: `u32`.
 pub struct GetMaxTodayWidth {}
 
-impl MsgSend for GetMaxTodayWidth {
+unsafe impl MsgSend for GetMaxTodayWidth {
 	type RetType = u32;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		v as _
 	}
 
@@ -239,10 +239,10 @@ pub struct GetMinReqRect<'a> {
 	pub bounds_rect: &'a mut RECT,
 }
 
-impl<'a> MsgSend for GetMinReqRect<'a> {
+unsafe impl<'a> MsgSend for GetMinReqRect<'a> {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -261,10 +261,10 @@ impl<'a> MsgSend for GetMinReqRect<'a> {
 /// Return type: `u32`.
 pub struct GetMonthDelta {}
 
-impl MsgSend for GetMonthDelta {
+unsafe impl MsgSend for GetMonthDelta {
 	type RetType = u32;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		v as _
 	}
 
@@ -286,10 +286,10 @@ pub struct GetMonthRange<'a> {
 	pub limits: &'a mut [SYSTEMTIME; 2],
 }
 
-impl<'a> MsgSend for GetMonthRange<'a> {
+unsafe impl<'a> MsgSend for GetMonthRange<'a> {
 	type RetType = u32;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		v as _
 	}
 
@@ -310,11 +310,11 @@ pub struct GetRange<'a> {
 	pub limits: &'a mut [SYSTEMTIME; 2],
 }
 
-impl<'a> MsgSend for GetRange<'a> {
+unsafe impl<'a> MsgSend for GetRange<'a> {
 	type RetType = co::GDTR;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
-		co::GDTR::from_raw(v as _)
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		unsafe { co::GDTR::from_raw(v as _) }
 	}
 
 	fn as_generic_wm(&mut self) -> WndMsg {
@@ -334,10 +334,10 @@ pub struct GetSelRange<'a> {
 	pub limits: &'a mut [SYSTEMTIME; 2],
 }
 
-impl<'a> MsgSend for GetSelRange<'a> {
+unsafe impl<'a> MsgSend for GetSelRange<'a> {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -358,10 +358,10 @@ pub struct GetToday<'a> {
 	pub info: &'a mut SYSTEMTIME,
 }
 
-impl<'a> MsgSend for GetToday<'a> {
+unsafe impl<'a> MsgSend for GetToday<'a> {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -380,10 +380,10 @@ impl<'a> MsgSend for GetToday<'a> {
 /// Return type: `bool`.
 pub struct GetUnicodeFormat {}
 
-impl MsgSend for GetUnicodeFormat {
+unsafe impl MsgSend for GetUnicodeFormat {
 	type RetType = bool;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		v != 0
 	}
 
@@ -404,10 +404,10 @@ pub struct HitTest<'a> {
 	pub test_info: &'a mut MCHITTESTINFO,
 }
 
-impl<'a> MsgSend for HitTest<'a> {
+unsafe impl<'a> MsgSend for HitTest<'a> {
 	type RetType = ();
 
-	unsafe fn isize_to_ret(&self, _: isize) -> Self::RetType {
+	fn convert_ret(&self, _: isize) -> Self::RetType {
 		()
 	}
 
@@ -429,10 +429,10 @@ pub struct SetCalendarBorder {
 	pub pixels: u32,
 }
 
-impl MsgSend for SetCalendarBorder {
+unsafe impl MsgSend for SetCalendarBorder {
 	type RetType = ();
 
-	unsafe fn isize_to_ret(&self, _: isize) -> Self::RetType {
+	fn convert_ret(&self, _: isize) -> Self::RetType {
 		()
 	}
 
@@ -453,10 +453,10 @@ pub struct SetCalId {
 	pub id: co::CAL,
 }
 
-impl MsgSend for SetCalId {
+unsafe impl MsgSend for SetCalId {
 	type RetType = ();
 
-	unsafe fn isize_to_ret(&self, _: isize) -> Self::RetType {
+	fn convert_ret(&self, _: isize) -> Self::RetType {
 		()
 	}
 
@@ -478,11 +478,11 @@ pub struct SetColor {
 	pub color: COLORREF,
 }
 
-impl MsgSend for SetColor {
+unsafe impl MsgSend for SetColor {
 	type RetType = Option<COLORREF>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
-		minus1_as_none(v).map(|v| COLORREF::from_raw(v as _))
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		minus1_as_none(v).map(|v| unsafe { COLORREF::from_raw(v as _) })
 	}
 
 	fn as_generic_wm(&mut self) -> WndMsg {
@@ -502,10 +502,10 @@ pub struct SetCurrentView {
 	pub view: co::MCMV,
 }
 
-impl MsgSend for SetCurrentView {
+unsafe impl MsgSend for SetCurrentView {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -526,10 +526,10 @@ pub struct SetCurSel<'a> {
 	pub info: &'a SYSTEMTIME,
 }
 
-impl<'a> MsgSend for SetCurSel<'a> {
+unsafe impl<'a> MsgSend for SetCurSel<'a> {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -550,10 +550,10 @@ pub struct SetDayState<'a> {
 	pub months: &'a [MONTHDAYSTATE],
 }
 
-impl<'a> MsgSend for SetDayState<'a> {
+unsafe impl<'a> MsgSend for SetDayState<'a> {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -574,10 +574,10 @@ pub struct SetFirstDayOfWeek {
 	pub first_day: u8,
 }
 
-impl MsgSend for SetFirstDayOfWeek {
+unsafe impl MsgSend for SetFirstDayOfWeek {
 	type RetType = (bool, u16);
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		(HIWORD(v as _) != 0, LOWORD(v as _))
 	}
 
@@ -598,10 +598,10 @@ pub struct SetMaxSelCount {
 	pub max_days: u8,
 }
 
-impl MsgSend for SetMaxSelCount {
+unsafe impl MsgSend for SetMaxSelCount {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -622,10 +622,10 @@ pub struct SetMonthDelta {
 	pub num_months: u8,
 }
 
-impl MsgSend for SetMonthDelta {
+unsafe impl MsgSend for SetMonthDelta {
 	type RetType = u8;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		v as _
 	}
 
@@ -647,10 +647,10 @@ pub struct SetRange<'a> {
 	pub limits: &'a [SYSTEMTIME; 2],
 }
 
-impl<'a> MsgSend for SetRange<'a> {
+unsafe impl<'a> MsgSend for SetRange<'a> {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -671,10 +671,10 @@ pub struct SetSelRange<'a> {
 	pub limits: &'a [SYSTEMTIME; 2],
 }
 
-impl<'a> MsgSend for SetSelRange<'a> {
+unsafe impl<'a> MsgSend for SetSelRange<'a> {
 	type RetType = SysResult<()>;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		zero_as_badargs(v).map(|_| ())
 	}
 
@@ -695,10 +695,10 @@ pub struct SetToday<'a> {
 	pub today: Option<&'a SYSTEMTIME>,
 }
 
-impl<'a> MsgSend for SetToday<'a> {
+unsafe impl<'a> MsgSend for SetToday<'a> {
 	type RetType = ();
 
-	unsafe fn isize_to_ret(&self, _: isize) -> Self::RetType {
+	fn convert_ret(&self, _: isize) -> Self::RetType {
 		()
 	}
 
@@ -719,10 +719,10 @@ pub struct SetUnicodeFormat {
 	pub use_unicode: bool,
 }
 
-impl MsgSend for SetUnicodeFormat {
+unsafe impl MsgSend for SetUnicodeFormat {
 	type RetType = bool;
 
-	unsafe fn isize_to_ret(&self, v: isize) -> Self::RetType {
+	fn convert_ret(&self, v: isize) -> Self::RetType {
 		v != 0
 	}
 
@@ -743,10 +743,10 @@ pub struct SizeRectToMin<'a> {
 	pub region: &'a mut RECT,
 }
 
-impl<'a> MsgSend for SizeRectToMin<'a> {
+unsafe impl<'a> MsgSend for SizeRectToMin<'a> {
 	type RetType = ();
 
-	unsafe fn isize_to_ret(&self, _: isize) -> Self::RetType {
+	fn convert_ret(&self, _: isize) -> Self::RetType {
 		()
 	}
 
